/*
 * Copyright(c) 1995,1996 by Gennady B. Sorokopud (gena@NetVision.net.il)
 *
 * This software can be freely redistributed and modified for 
 * non-commercial purposes as long as above copyright
 * message and this permission notice appear in all
 * copies of distributed source code and included as separate file
 * in binary distribution.
 *
 * Any commercial use of this software requires author's permission.
 *
 * This software is provided "as is" without expressed or implied
 * warranty of any kind.
 * Under no circumstances is the author responsible for the proper
 * functioning of this software, nor does the author assume any
 * responsibility for damages incurred with its use.
 *
 */

/* $Id: acconfig.h,v 2.3 1998/03/23 15:41:57 gena Exp $
 */

#ifndef CONFIG_H
#define CONFIG_H

@TOP@

/* some systems does not have XReadBitmapFileData */
#undef	HAVE_XREADBITMAPFILEDATE

/* some systems does not have XSupportsLocale */
#undef	HAVE_XSUPPORTSLOCALE

/* Where new mail is spooled */
#undef _CONF_PATH_MAILDIR

/* How to print */
#undef _PATH_LPR
#undef _PATH_LP

/* Where sendmail lives */
#undef _CONF_PATH_SENDMAIL

/* Where to find pgp executable */
#undef _PATH_PGP

/* Where to find ispell executable */
#undef _PATH_ISPELL

@BOTTOM@

#if defined(__SVR4) || defined(__svr4__)
#define SVR4
#endif

#if defined(__STDC__)
#define	USE_STDARG
#endif

#if defined(SCO)
#define	MAXPATHLEN	PATHSIZE
#endif

#endif
